@@ -58,7 +58,7 @@ class PlaceInput(BaseDictKey):
 class LocationInput(BaseDictKey):
     artifact: str
     representation: List[str]
-    artifact_archival_copy: str
+    artifactArchivalCopy: str
 
     def validate(self):
         if self.representation is None and self.artifact is None:
